@@ -1,3 +1,3 @@
 from voxelmap.main import *
-from voxelmap.goxel import *
+from voxelmap.data import *
 from voxelmap.mapto3d import *
\ No newline at end of file
